// java wrapper for vtkTypeUInt64Array object
//

package vtk;
import vtk.*;

public class vtkTypeUInt64Array extends vtkUnsignedLongLongArray
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long FastDownCast_2(vtkAbstractArray id0);
  public vtkTypeUInt64Array FastDownCast(vtkAbstractArray id0) {
    long temp = FastDownCast_2(id0);

    if (temp == 0) return null;
    return (vtkTypeUInt64Array)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkTypeUInt64Array() { super(); }

  public vtkTypeUInt64Array(long id) { super(id); }
  public native long   VTKInit();

}
